"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = reloadSession;

var _request = _interopRequireDefault(require("webdriver/build/request"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function reloadSession() {
  const oldSessionId = this.sessionId;
  await this.deleteSession();
  const {
    w3cCaps,
    jsonwpCaps
  } = this.options.requestedCapabilities;
  const sessionRequest = new _request.default('POST', '/session', {
    capabilities: w3cCaps,
    desiredCapabilities: jsonwpCaps
  });
  const response = await sessionRequest.makeRequest(this.options);
  const newSessionId = response.sessionId || response.value && response.value.sessionId;
  this.sessionId = newSessionId;

  if (Array.isArray(this.options.onReload) && this.options.onReload.length) {
    await Promise.all(this.options.onReload.map(hook => hook(oldSessionId, newSessionId)));
  }

  return newSessionId;
}